@@ -4,7 +4,7 @@ use super::author::*;
 
 #[test]
 fn has_an_author() {
-    let author = Author::new("The Name", "email@example.com", None);
+    let author = Author::new("The Name".into(), "email@example.com".into(), None);
 
     assert_eq!(author.name(), "The Name");
     assert_eq!(author.email(), "email@example.com");
@@ -13,7 +13,11 @@ fn has_an_author() {
 
 #[test]
 fn has_an_signing_key() {
-    let author = Author::new("The Name", "email@example.com", Some("0A46826A"));
+    let author = Author::new(
+        "The Name".into(),
+        "email@example.com".into(),
+        Some("0A46826A".into()),
+    );
 
-    assert_eq!(author.signingkey(), Some("0A46826A".into()));
+    assert_eq!(author.signingkey(), Some("0A46826A"));
 }
